@@ -22,10 +22,10 @@
 from base_device_module import deviceModule
 
 def getModule(m,d):
-  return(n900(m,d))
+  return(device_n900(m,d))
 
-class n900(deviceModule):
-  """A sample modRana device-specific module"""
+class device_n900(deviceModule):
+  """A N900 modRana device-specific module"""
   
   def __init__(self, m, d):
     deviceModule.__init__(self, m, d)
@@ -45,9 +45,7 @@ class n900(deviceModule):
 
     
   def update(self):
-    # Get and set functions are used to access global data
-    self.set('num_updates', self.get('num_updates', 0) + 1)
-    #print "Updated %d times" % (self.get('num_updates'))
+    """initialize the automatic rotation"""
     if not self.done:
       if self.topWindow: #TODO: do this more efficiently
         self.startAutorotation()
@@ -92,6 +90,9 @@ class n900(deviceModule):
     elif rotationMode == "portrait":
       return 2
 
+  def getLogFolderPath(self):
+    return "/home/user/MyDocs/" #N900 specific log folder
+
     
 
 
