@@ -35,12 +35,6 @@ class notification(ranaModule):
     self.draw = False
     self.redrawn = None
 
-    
-  def update(self):
-#    # Get and set functions are used to access global data
-#    self.set('num_updates', self.get('num_updates', 0) + 1)
-#    #print "Updated %d times" % (self.get('num_updates'))
-    self.set('num_updates', self.get('num_updates', 0) + 1)
 
   def handleMessage(self, message, type, args):
     """the first part is the message, that will be displayed,
